# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateCardPaymentContactlessPOIRequest(object):

    """Implementation of the 'CreateCardPaymentContactlessPOIRequest' model.

    TODO: type model description here.

    Attributes:
        system_name (string): system name
        model (string): model
        provider (string): provider
        serial_number (string): serial number
        version_number (string): version number

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "system_name":'system_name',
        "model":'model',
        "provider":'provider',
        "serial_number":'serial_number',
        "version_number":'version_number'
    }

    def __init__(self,
                 system_name=None,
                 model=None,
                 provider=None,
                 serial_number=None,
                 version_number=None):
        """Constructor for the CreateCardPaymentContactlessPOIRequest class"""

        # Initialize members of the class
        self.system_name = system_name
        self.model = model
        self.provider = provider
        self.serial_number = serial_number
        self.version_number = version_number


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        system_name = dictionary.get('system_name')
        model = dictionary.get('model')
        provider = dictionary.get('provider')
        serial_number = dictionary.get('serial_number')
        version_number = dictionary.get('version_number')

        # Return an object of this model
        return cls(system_name,
                   model,
                   provider,
                   serial_number,
                   version_number)


